==> bettertrims-4.0.0%2B1.21.1-fabric-sources.jar: com/bawnorton/bettertrims/mixin/property/ability/equipment/LivingEntityMixin.java <==
package com.bawnorton.bettertrims.mixin.property.ability.equipment;

import com.bawnorton.bettertrims.property.TrimProperties;
import com.bawnorton.bettertrims.property.TrimProperty;
import com.bawnorton.bettertrims.property.ability.TrimAbilityComponents;
import com.bawnorton.bettertrims.property.ability.runner.TrimEntityAbilityRunner;
import com.bawnorton.bettertrims.property.ability.runner.TrimToggleAbilityRunner;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import dev.kikugie.fletching_table.annotation.MixinEnvironment;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.function.BiConsumer;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1320;
import net.minecraft.class_1322;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_6880;

@Mixin(class_1309.class)
abstract class LivingEntityMixin extends class_1297 {
	LivingEntityMixin(class_1299<?> entityType, class_1937 level) {
		super(entityType, level);
	}

	//? if 1.21.8 {
    /*@Inject(
        method = "stopLocationBasedEffects",
        at = @At("TAIL")
    )
    private void stopTrimEquipmentBasedEffects(ItemStack stack, EquipmentSlot slot, AttributeMap attributeMap, CallbackInfo ci) {
    *///?} elif 1.21.1 {
	@WrapOperation(
			method = "collectEquipmentChanges",
			at = @At(
					value = "INVOKE",
					target = "Lnet/minecraft/world/item/ItemStack;forEachModifier(Lnet/minecraft/world/entity/EquipmentSlot;Ljava/util/function/BiConsumer;)V"
			)
	)
	private void stopTrimEquipmentBasedEffects(class_1799 stack, class_1304 slot, BiConsumer<class_6880<class_1320>, class_1322> action, Operation<Void> original) {
		original.call(stack, slot, action);
		//?}
		if (!(method_37908() instanceof class_3218 level)) return;

		class_1309 self = (class_1309) (Object) this;
		for (TrimProperty property : TrimProperties.getProperties(level)) {
			for (TrimToggleAbilityRunner<?> ability : property.getToggleAbilityRunners(TrimAbilityComponents.EQUIPPED)) {
				ability.runStop(level, self, stack, slot);
			}
		}
	}

	//? if 1.21.8 {
    /*@WrapOperation(
        method = "collectEquipmentChanges",
        at = @At(
            value = "INVOKE",
            target = "Lnet/minecraft/world/item/enchantment/EnchantmentHelper;runLocationChangedEffects(Lnet/minecraft/server/level/ServerLevel;Lnet/minecraft/world/item/ItemStack;Lnet/minecraft/world/entity/LivingEntity;Lnet/minecraft/world/entity/EquipmentSlot;)V"
        )
    )
    private void startTrimLocationBasedEffects(ServerLevel level, ItemStack stack, LivingEntity entity, EquipmentSlot slot, Operation<Void> original) {
        original.call(level, stack, entity, slot);
    *///?} elif 1.21.1 {
	@WrapOperation(
			method = "collectEquipmentChanges",
			at = @At(
					value = "INVOKE",
					target = "Lnet/minecraft/world/item/ItemStack;forEachModifier(Lnet/minecraft/world/entity/EquipmentSlot;Ljava/util/function/BiConsumer;)V"
			)
	)
	private void startTrimLocationBasedEffects(class_1799 stack, class_1304 slot, BiConsumer<class_6880<class_1320>, class_1322> action, Operation<Void> original) {
		original.call(stack, slot, action);
		if (!(method_37908() instanceof class_3218 level)) return;
		//?}
		class_1309 self = (class_1309) (Object) this;
		for (TrimProperty property : TrimProperties.getProperties(level)) {
			for (TrimToggleAbilityRunner<?> ability : property.getToggleAbilityRunners(TrimAbilityComponents.EQUIPPED)) {
				ability.runStart(level, self);
			}
		}
	}

	@WrapOperation(
			method = "baseTick",
			at = @At(
					value = "INVOKE",
					target = "Lnet/minecraft/world/item/enchantment/EnchantmentHelper;tickEffects(Lnet/minecraft/server/level/ServerLevel;Lnet/minecraft/world/entity/LivingEntity;)V"
			)
	)
	private void tickTrimEffects(class_3218 level, class_1309 entity, Operation<Void> original) {
		original.call(level, entity);
		for (TrimProperty property : TrimProperties.getProperties(level)) {
			for (TrimEntityAbilityRunner<?> ability : property.getEntityAbilityRunners(TrimAbilityComponents.TICK)) {
				ability.runTick(level, entity, entity, method_19538());
			}
			for (TrimToggleAbilityRunner<?> ability : property.getToggleAbilityRunners(TrimAbilityComponents.EQUIPPED)) {
				ability.update(level, entity);
			}
			if (field_6012 % (int) level.method_54719().method_54748() == 0) {
				for (TrimEntityAbilityRunner<?> ability : property.getEntityAbilityRunners(TrimAbilityComponents.SECOND)) {
					ability.runTick(level, entity, entity, method_19538());
				}
			}
		}
	}
}

==> bettertrims-4.0.2%2B1.21.10-fabric-sources.jar: com/bawnorton/bettertrims/mixin/property/ability/equipment/LivingEntityMixin.java <==
package com.bawnorton.bettertrims.mixin.property.ability.equipment;

import com.bawnorton.bettertrims.property.TrimProperties;
import com.bawnorton.bettertrims.property.TrimProperty;
import com.bawnorton.bettertrims.property.ability.TrimAbilityComponents;
import com.bawnorton.bettertrims.property.ability.runner.TrimEntityAbilityRunner;
import com.bawnorton.bettertrims.property.ability.runner.TrimToggleAbilityRunner;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import dev.kikugie.fletching_table.annotation.MixinEnvironment;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.function.BiConsumer;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_5131;

@Mixin(class_1309.class)
abstract class LivingEntityMixin extends class_1297 {
	LivingEntityMixin(class_1299<?> entityType, class_1937 level) {
		super(entityType, level);
	}

	//? if >=1.21.8 {
	@Inject(
			method = "stopLocationBasedEffects",
			at = @At("TAIL")
	)
	private void stopTrimEquipmentBasedEffects(class_1799 stack, class_1304 slot, class_5131 attributeMap, CallbackInfo ci) {
		//?} else {
	/*@WrapOperation(
			method = "collectEquipmentChanges",
			at = @At(
					value = "INVOKE",
					target = "Lnet/minecraft/world/item/ItemStack;forEachModifier(Lnet/minecraft/world/entity/EquipmentSlot;Ljava/util/function/BiConsumer;)V"
			)
	)
	private void stopTrimEquipmentBasedEffects(ItemStack stack, EquipmentSlot slot, BiConsumer<Holder<Attribute>, AttributeModifier> action, Operation<Void> original) {
		original.call(stack, slot, action);
		*///?}
		if (!(method_73183() instanceof class_3218 level)) return;

		class_1309 self = (class_1309) (Object) this;
		for (TrimProperty property : TrimProperties.getProperties(level)) {
			for (TrimToggleAbilityRunner<?> ability : property.getToggleAbilityRunners(TrimAbilityComponents.EQUIPPED)) {
				ability.runStop(level, self, stack, slot);
			}
		}
	}

	//? if >=1.21.8 {
	@WrapOperation(
			method = "collectEquipmentChanges",
			at = @At(
					value = "INVOKE",
					target = "Lnet/minecraft/world/item/enchantment/EnchantmentHelper;runLocationChangedEffects(Lnet/minecraft/server/level/ServerLevel;Lnet/minecraft/world/item/ItemStack;Lnet/minecraft/world/entity/LivingEntity;Lnet/minecraft/world/entity/EquipmentSlot;)V"
			)
	)
	private void startTrimLocationBasedEffects(class_3218 level, class_1799 stack, class_1309 entity, class_1304 slot, Operation<Void> original) {
		original.call(level, stack, entity, slot);
		//?} else {
	/*@WrapOperation(
			method = "collectEquipmentChanges",
			at = @At(
					value = "INVOKE",
					target = "Lnet/minecraft/world/item/ItemStack;forEachModifier(Lnet/minecraft/world/entity/EquipmentSlot;Ljava/util/function/BiConsumer;)V"
			)
	)
	private void startTrimLocationBasedEffects(ItemStack stack, EquipmentSlot slot, BiConsumer<Holder<Attribute>, AttributeModifier> action, Operation<Void> original) {
		original.call(stack, slot, action);
		if (!(level() instanceof ServerLevel level)) return;
		*///?}
		class_1309 self = (class_1309) (Object) this;
		for (TrimProperty property : TrimProperties.getProperties(level)) {
			for (TrimToggleAbilityRunner<?> ability : property.getToggleAbilityRunners(TrimAbilityComponents.EQUIPPED)) {
				ability.runStart(level, self);
			}
		}
	}

	@WrapOperation(
			method = "baseTick",
			at = @At(
					value = "INVOKE",
					target = "Lnet/minecraft/world/item/enchantment/EnchantmentHelper;tickEffects(Lnet/minecraft/server/level/ServerLevel;Lnet/minecraft/world/entity/LivingEntity;)V"
			)
	)
	private void tickTrimEffects(class_3218 level, class_1309 entity, Operation<Void> original) {
		original.call(level, entity);
		for (TrimProperty property : TrimProperties.getProperties(level)) {
			for (TrimEntityAbilityRunner<?> ability : property.getEntityAbilityRunners(TrimAbilityComponents.TICK)) {
				ability.runTick(level, entity, entity, method_73189());
			}
			for (TrimToggleAbilityRunner<?> ability : property.getToggleAbilityRunners(TrimAbilityComponents.EQUIPPED)) {
				ability.update(level, entity);
			}
			if (field_6012 % (int) level.method_54719().method_54748() == 0) {
				for (TrimEntityAbilityRunner<?> ability : property.getEntityAbilityRunners(TrimAbilityComponents.SECOND)) {
					ability.runTick(level, entity, entity, method_73189());
				}
			}
		}
	}
}
